======
dpaste
======

dpaste is a Django based pastebin. It's intended to run separately but its also
possible to be installed into an existing Django project like a regular app.


Contents:

.. toctree::
   :maxdepth: 1

   testing
   installation
   integration
   settings
   api

..
    Indices and tables
    ==================
    * :ref:`genindex`
    * :ref:`modindex`
    * :ref:`search`

